pub fn populate_module_category(chip: Chip, options: &mut [GeneratorOptionItem])Expand description
Populates the module category in the template options with chip-specific modules.
pub fn populate_module_category(chip: Chip, options: &mut [GeneratorOptionItem])Populates the module category in the template options with chip-specific modules.